import axios from 'axios'
import { getStore, setStore } from '@/util/store'
import { Toast } from 'mint-ui'
import router from '@/router/index'

axios.defaults.timeout = 30000
// 返回其他状态吗
axios.defaults.validateStatus = function (status) {
  return status // 默认的
}
// 跨域请求，允许保存cookie
axios.defaults.withCredentials = true
// request拦截器
axios.interceptors.request.use(config => {
  let token = getStore({name: 'access_token'})
  if (token) {
    config.headers['Authorization'] = 'Bearer ' + token
  }
  return config
}, error => {
  // Do something with request error
  console.log(error) // for debug
  Promise.reject(error)
})

// respone拦截器
axios.interceptors.response.use(response => {
  const res = response.data ? response.data : response
  const status = Number(response.status) || 200
  console.log('response status:' + status)
  if (status !== 200) {
    if (status === 401) {
      Toast({
        message: '您因长时间逗留，验证已过期，正在刷新！',
        position: 'center',
        duration: 5 * 1000
      })
      setStore({ name: 'access_token', content: '' })
      setTimeout(function () {
        window.location.reload()
      }, 5 * 1000)
    } else if (status === 403) {
      if (res.msg === '请先进行实名认证') { // 跳转至社区推荐页
        router.push({
          path: '/recommend'
        })
      }
    } else {
      if (!res.msg) {
        res.msg = '内部服务器错误[500]'
      }
      return Promise.reject(new Error(res.msg))
    }
  }

  return res
}, error => {
  console.log('错误' + error)// for debug
  Toast({
    message: error.message,
    position: 'center',
    duration: 5 * 1000
  })
  return Promise.reject(new Error(error))
})

export default axios
